@@ -27,19 +27,18 @@ impl Places {
             base_url, id, self.api_key
         );
 
-        let res = match ureq::get(&url)
-            .call() {
-                Ok(r) => r,
-                Err(e) => {
-                    return Err(GoogleMapPlaceError::Unknown(e.to_string()));
-                },
-            };
+        let res = match ureq::get(&url).call() {
+            Ok(r) => r,
+            Err(e) => {
+                return Err(GoogleMapPlaceError::Unknown(e.to_string()));
+            }
+        };
 
         let body = match res.into_json::<Response>() {
             Ok(r) => r,
             Err(e) => {
                 return Err(GoogleMapPlaceError::Unknown(e.to_string()));
-            },
+            }
         };
 
         Ok(body)
@@ -72,7 +71,9 @@ mod tests {
     #[test]
     fn test_valid_map_place() {
         let _m = setup_mock("place-001");
-        let place = Places { api_key: API_KEY.into() };
+        let place = Places {
+            api_key: API_KEY.into(),
+        };
         let res = match place.get_map_place("place-001") {
             Ok(b) => b,
             Err(_e) => {
@@ -81,18 +82,34 @@ mod tests {
             }
         };
 
-        if let Response::OK { result } = res {
-            assert_eq!(result.address_components.len(), 7);
-        } else {
-            assert!(false);
-        }
+        let result = match res {
+            Response::OK { result } => {
+                assert_eq!(result.address_components.len(), 7);
+                result
+            }
+            _ => {
+                assert!(false);
+                return;
+            }
+        };
+
+        assert_eq!(result.street_number().unwrap(), "7");
+        assert_eq!(result.route().unwrap(), "Leboh Palas");
+        assert_eq!(result.sublocality().unwrap(), "Taman Selatan");
+        assert_eq!(result.postal_code().unwrap(), "41200");
+        assert_eq!(result.city().unwrap(), "Klang");
+        assert_eq!(result.state().unwrap(), "Selangor");
+        assert_eq!(result.country().unwrap(), "Malaysia");
+        assert_eq!(result.country_code().unwrap(), "MY");
     }
 
     #[test]
     fn test_invalid_map_place() {
         let _m = setup_mock("place-invalid");
 
-        let place = Places { api_key: API_KEY.into() };
+        let place = Places {
+            api_key: API_KEY.into(),
+        };
         let res = match place.get_map_place("place-invalid") {
             Ok(b) => b,
             Err(_e) => {
@@ -112,7 +129,9 @@ mod tests {
     fn test_denied_map_place() {
         let _m = setup_mock("place-denied");
 
-        let place = Places { api_key: API_KEY.into() };
+        let place = Places {
+            api_key: API_KEY.into(),
+        };
         let res = match place.get_map_place("place-denied") {
             Ok(b) => b,
             Err(_e) => {
